#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 05/07/2001
#################################################################################
#
# Realm - Script part of Webchat designed to use the realms
# Copyright (C) 2000-2001  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2E 0K9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use FileHandle;							# Filehandle

use strict;							# Strict variable enforcement

use Webchat::Comm;						# Communication handler
use Webchat::Database;						# Database handler
use Webchat::Login;						# Login functionality
use Webchat::Param;						# Parameter control
use Webchat::Post;						# Post handler
use Webchat::Who;						# Who is on


#################################################################################
# Data Members
#################################################################################
my $Database;							# Database handle
my $cgi;							# Common gateway interface handle

my $javascript;							# Javascript preferences
my $chatpref;							# Chat preferences
my $inline;							# Inline parameters
my $url;							# URL path

my %param;							# Parameter hash
my %realm;							# Realm hash


#################################################################################
# Program Area
#################################################################################

	$cgi = new CGI;						# Create CGI Handle
	$url = $cgi->url();					# URL

	Webchat::Database::DatabaseConnect(\$Database);		# Connect to MySQL
	Webchat::Database::GetHashRealm($Database, \%realm);	# Link to hash
	Webchat::Param::GetParam($cgi, \%param);		# Retreive parameters

	if ( Webchat::Login::GetVerificationNormal($Database, $cgi, \%param) )
	{
		# Make sure logins are possible
		Webchat::Login::CheckLegality($Database, $cgi, \%param, \%realm);

		# Retreive javascript and chat preferences
		($javascript, $chatpref) = Webchat::Database::DataGetChatOptions($Database, $param{'USER'});

		# Handle post writing
		Webchat::Comm::DataWrite($Database, $cgi, \%param);

		# Framed chat
		if (($chatpref eq 'framed') && ($javascript eq 'yes'))
		{
			# Only do following if called with no parameters
			unless ((defined($param{'MAIN'})) || (defined($param{'COMM'})))
			{
				# Retreive parameter list
				$inline = Webchat::Param::EmbedInline($Database, $cgi, %param);

				# Print file header
				print $cgi->header();

				# Print header
				print "<HTML>\n<HEAD>\n\t<TITLE>$param{'ROOM'}</TITLE>\n</HEAD>\n\n";

				# Print frameset
				print "<FRAMESET ROWS=\"*,115\">\n";
				print "\t<FRAME NAME=\"Main\" SRC=\"$url$inline&MAIN=aff\">\n";
				print "\t<FRAME NAME=\"Comm\" SRC=\"$realm{'LnkBlank'}\">\n";
				print "</FRAMESET>\n";

				# End of HTML
				print "</HTML>\n";
			}
	
			# Message display area
			if (defined($param{'MAIN'}))
			{ 
				# File and HTML header
				print $cgi->header(-target=>'Main');
				Webchat::Database::DocumentGetHeaderFramed($Database);

				# Posting related
				Webchat::Post::HandlePosts($Database, \%param); 

				# Javascript
				print "\n<SCRIPT LANGUAGE=\"javascript\">\n";
				print "<!-- \n\n";
				print "function CommReset()\n";
				print "{\n"; 
				print "\ttop.Comm.document.Comm.POST.value = ''; \n";
				print "\ttop.Comm.document.Comm.NUM.value = '$param{'NUM'}'; \n";
				print "}\n";
				print "// -->\n"; 
				print "\n</SCRIPT>\n";

				# Parameter handler
				delete $param{'MAIN'};
				$inline = Webchat::Param::EmbedInline($Database, $cgi, %param, 'COMM', 'True'); 

				# Activation button
				print "<A HREF=\"$url/realm.plx$inline\" TARGET=\"Comm\">$realm{'TagPost'}</A>";

				print $cgi->end_html();
			}

			# Comm panel
			if (defined($param{'COMM'}))
			{ 
				# Cleanup
				delete $param{'COMM'};

				# Communications panel
				Webchat::Comm::CommIndependant($Database, $cgi, \%param); 
			}
		}


		# Streaming chat with autoscroll
		elsif (($chatpref eq 'autoscroll') && ($javascript eq 'yes')) 
		{
			# Only do following if called with no parameters
			unless ((defined($param{'MAIN'})) || (defined($param{'COMM'})))
			{
				# Retreive parameter list
				$inline = Webchat::Param::EmbedInline($Database, $cgi, %param);

				# Print file header
				print $cgi->header();				
				
				# Print header
				print "<HTML>\n<HEAD>\n\t<TITLE>$param{'ROOM'}</TITLE>\n</HEAD>\n\n";

				# Print frameset
				print "<FRAMESET COLS=\"65,*\">\n";
				print "\t<FRAME NAME=\"Remote\" SRC=\"$realm{'LnkRemote'}\">\n";
				print "\t<FRAMESET ROWS=\"*,115\">\n";
				print "\t\t<FRAME NAME=\"Main\" SRC=\"$url$inline&MAIN=aff\">\n";
				print "\t\t<FRAME NAME=\"Comm\" SRC=\"$url$inline&COMM=aff\">\n";
				print "\t</FRAMESET>\n";
				print "</FRAMESET>\n";

				# End of HTML
				print "</HTML>\n";
			}	
	
			# Message display area
			if (defined($param{'MAIN'}))
			{ 
				# Flush standard output				
				autoflush STDOUT 1;
				print "";

				# File header
				print $cgi->header(-target=>'Main');

				# Java enabled post window
				Webchat::Database::DocumentGetHeaderPlain($Database);
				Webchat::Post::HandleStream($Database, $cgi, \%param); 
				print $cgi->end_html();
			}

			# Comm panel
			if (defined($param{'COMM'}))
			{ Webchat::Comm::CommAutoScroll($Database, $cgi, \%param); }
		}

		# Streaming chat
		elsif (($chatpref eq 'stream') || ($chatpref eq 'autoscroll'))
		{
			# Only do following if called with no parameters
			unless ((defined($param{'MAIN'})) || (defined($param{'COMM'})))
			{
				# Retreive parameter list
				$inline = Webchat::Param::EmbedInline($Database, $cgi, %param);

				# Print file header
				print $cgi->header();				
				
				# Print header
				print "<HTML>\n<HEAD>\n\t<TITLE>$param{'ROOM'}</TITLE>\n</HEAD>\n\n";

				# Print frameset
				print "<FRAMESET ROWS=\"*,115\">\n";
				print "\t<FRAME NAME=\"Main\" SRC=\"$url$inline&MAIN=aff\">\n";
				print "\t<FRAME NAME=\"Comm\" SRC=\"$url$inline&COMM=aff\">\n";
				print "</FRAMESET>";

				# End of HTML
				print "</HTML>\n";
			}	
	
			# Message display area
			if (defined($param{'MAIN'}))
			{ 
				# Flush standard output				
				autoflush STDOUT 1;
				print "";

				# File header
				print $cgi->header(-target=>'Main');

				# Posting related
				Webchat::Database::DocumentGetHeaderPlain($Database);
				Webchat::Post::HandleStream($Database, $cgi, \%param); 
				print $cgi->end_html();
			}

			# Comm panel
			if (defined($param{'COMM'}))
			{ Webchat::Comm::CommStream($Database, $cgi, \%param); }
		}


		# Basic chat system
		else
		{
			# Print file and HTML header
			print $cgi->header();
			Webchat::Database::DocumentGetHeaderPlain($Database);

			# Message display and posting
			Webchat::Post::HandlePosts($Database, \%param); 
			Webchat::Comm::CommDependant($Database, $cgi, \%param);

			# HTML footer
			print $cgi->end_html();
		}
	}

	$Database->disconnect();				# Disconnect database handle

#################################################################################
# Sub-Routines
#################################################################################
